# pylint: disable=unused-import
# pylint: disable=line-too-long
'''
    A module of utility methods used for generating random data or performing various
    actions randomly.

    ----------

    Meta
    ----------
    `author`: Colemen Atwood
    `created`: 06-03-2022 10:22:15
    `memberOf`: rand
    `version`: 1.0
    `method_name`: rand
'''





from faker import Faker

from utils.object_utils import rand_option as option
from utils.string_generation import text,phone,email,url,abstract_name,rand
fake = Faker()







